@@ -4,7 +4,7 @@ my $loaded;
 
 use strict;
 
-BEGIN { $| = 1; print "1..4\n"; }
+BEGIN { $| = 1; print "1..5\n"; }
 END { print "not ok 1\n" unless $loaded; }
 
 use Tie::Scalar::Decay;
@@ -42,19 +42,17 @@ if($scalar == 10) {                      # good, hasn't decayed yet
         print "not ok 4\n";
 }
 
-# Don't do this test - too sensitive to system load
-#
-# tie $scalar, 'Tie::Scalar::Decay', (     # test a coderef FUNCTION
-# 	VALUE    => 0,                   # and a sub-second PERIOD
-# 	FUNCTION => \&increment,
-# 	PERIOD   => 0.1
-# );
-# my $sequence='';
-# while($scalar<10) {
-# 	select(undef, undef, undef, 0.1);
-# 	$sequence.="$scalar ";
-# }
-# print "not " unless($sequence eq '0 1 2 3 4 5 6 7 8 9 10 ');
-# print "ok 5\n";
+tie $scalar, 'Tie::Scalar::Decay', (     # test a coderef FUNCTION
+	VALUE    => 0,                   # and a sub-second PERIOD
+	FUNCTION => \&increment,
+	PERIOD   => 0.1
+);
+my $sequence='';
+while($scalar<10) {
+	select(undef, undef, undef, 0.1);
+	$sequence.="$scalar ";
+}
+print "not " unless($sequence eq '0 1 2 3 4 5 6 7 8 9 10 ');
+print "ok 5\n";
 
 sub increment { $_[0]+1; }
